#!/bin/bash

STEPS_LOG=/opt/.ubuntu-toolkit.log

# Función para las preguntas
ask() {
	while true; do
		if [ "${2:-}" = "S" ]; then
			PROMPT="S/n"
			DEFAULT=S
		elif [ "${2:-}" = "N" ]; then
			PROMPT="s/N"
			DEFAULT=N
		else
			PROMPT="s/n"
			DEFAULT=
		fi

		# Realizar la pregunta
		read -p "$1 ($PROMPT) " REPLY

		# Se ha optado por defecto?
		if [ -z "$REPLY" ]; then
			REPLY=$DEFAULT
		fi

		# Verificar si la respuesta es válida
		# NOTA: convertimos la respuesta a "uppercase"
		case "${REPLY^^}" in
			S|Y)
				return 0
				;;
			
			N) 
				return 1 
				;;
		esac
	done
}

# Función para aplicar parches
patchfile() {
    # param 1: archivo a aplicar parche
    # param 2: parche
    patch -f $1 $2 || { echo "Error aplicando parche $2 a $1"; return 1; }
}

textinfile() {
    # param 1: archivo donde agregar el texto
    # param 2: (opcional) patron de busqueda. Si se encuentra no se agrega el texto
    if ! [ -z "$2" ]; then
        grep -q "$2" "$1" && return 0
    fi
    cat >> "$1"
}

lineinfile() {
    # param 1: archivo donde agregar la linea
    # param 2: (opcional) patron de busqueda
    # param 3: linea a agregar
    PATTERN="$2"
    LINE="$3"
    if [ $# -eq 2 ]; then
        PATTERN="^$2"
        LINE="$2"
    fi
    if grep -q "$PATTERN" "$1"; then
        sed -i "s/$PATTERN.*\$/$LINE/" "$1"
    else
        textinfile "$1" "$PATTERN" <<EOF
$LINE
EOF
    fi
}

is_systemd() {
    case "$(readlink -f /proc/1/exe || true)" in
    *systemd*)
        return 0
        ;;
    *)
        return 1
        ;;
    esac
}

is_supported_ubuntu() {
    case "$(lsb_release -sc || echo UNKNOWN)" in
        trusty|xenial|bionic)
            return 0
            ;;
        *)
            return 1
            ;;
    esac
}

i_am_root() {
    [ $(whoami) = "root" ]
}

restart_service() {
    if is_systemd; then
        systemctl restart "$1"
    else
        service "$1" restart
    fi
}

die() {
    # param 1: Mensaje
    # param 2 (opcional): exit code
    echo $1 >&2
    if [ -z $2 ]; then
        exit 1
    else
        exit $2
    fi
}

dieOnError() {
    # param 1: Mensaje
    # param 2 (opcional): exit code
    if [ $? -ne 0 ]; then
        die "$1" $2 
    fi
}

logStep() {
    # param 1: nombre del step
    echo -e "$1 ---- $(date +"%H:%m %d/%m/%Y")"  >> "$STEPS_LOG"
}

stepAlreadyRun() {
    # param 1: nombre del step
    grep -q "^$1 " $STEPS_LOG
}

setUpInstallConfig() {
    mkdir -p /opt
    export TK_CONFIG_FILE=/opt/.ubuntu-toolkit.conf
    if ! [ -f "$TK_CONFIG_FILE" ]; then
        cp install-default-settings "$TK_CONFIG_FILE"
    fi
}

editInstallConfig() {
    if [ -z "$TK_CONFIG_FILE" ]; then
        setUpInstallConfig
    fi
    ${EDITOR:-nano} "$TK_CONFIG_FILE"
}

configChanged() {
    if diff -q install-default-settings "$TK_CONFIG_FILE" > /dev/null 2>&1; then
        return 1
    fi
    return 0
}

if [ -z $EDITOR ]; then
    EDITOR=/bin/nano
fi

if [ -n "$TK_CONFIG_FILE" ] && [ -f "$TK_CONFIG_FILE" ]; then
    . "$TK_CONFIG_FILE"
fi
