#!/bin/bash

. ./functions.sh

if ! i_am_root; then
    die "Ejecutar como root!"
fi

if ! is_supported_ubuntu && [ -z "$TOOLKIT_IGNORE_UBUNTU_RELEASE" ]; then
    echo "La versión de ubuntu no es soportada"
    echo "Para instalar de todas formas, exportar TOOLKIT_IGNORE_UBUNTU_RELEASE=y"
    exit 1
fi

echo "Iniciando configuración general"
editInstallConfig

if ! configChanged; then
    echo "No se establecieron los parámetros de instalación. No se hará nada."
    exit 1
fi

export TK_CONFIG_FILE
. "$TK_CONFIG_FILE"

echo "Instalando packages"
steps/packages-task.sh base

echo "Instalando fierroutils"
steps/fierroutils.sh

echo "Instalando locales"
steps/locales.sh

if [ -n "$TK_TASK_FIERROSERVER" ]; then
    if [ -n "$TK_TASK_FIERROSERVER_POSTGRESQL" ]; then
        echo "Instalando postgresql"
        steps/postgresql.sh
    fi

    echo "Instalando fierroserver"
    steps/fierroserver.sh

    echo "Instalando fierrowebclient"
    steps/fierrowebclient.sh

    echo "Configurando flask"
    steps/flask.sh

    if [ -n "$TK_TASK_OFFLINE" ]; then
        echo "Instalando queueserver"
        steps/queueserver.sh
    fi

fi

if [ -n "$TK_TASK_FIERROCLIENT" ]; then
    if [ -n "$TK_TASK_FIERROCLIENT_DESKTOP" ]; then
        echo "Instalando packages de escritorio para instalación de client"
        steps/packages-task.sh desktop
    fi

    echo "Instalando fierropanel"
    steps/fierropanel.sh

    echo "Instalando bindeps"
    steps/bindeps.sh

    echo "Instalando libpng"
    steps/libpng.sh

    echo "Instalando fierroclient"
    steps/fierroclient.sh

    echo "Instalando fiscalprinter"
    steps/fiscalprinter.sh

    if [ -n "$TK_TASK_OFFLINE" ]; then
        echo "Instalando fierroclient-offline"
        steps/fierro-offline.sh
    fi
 
fi

echo "Instalando patches"
steps/patches-fierro.sh

echo "Configurando hostname"
steps/hostname.sh
