
import unittest

import conf

from utils import get_shell_variable


CLIENT_CONFIG_FILE_TEMPLATE = '/etc/opt/fierro%s/clientserver.conf'


class TestFierroClient(unittest.TestCase):

    def __init__(self, methodName, fierro_instance=''):
        super(TestFierroClient, self).__init__(methodName)

        self.fierro_instance = fierro_instance
        self.test_method_name = methodName
        self.client_config_file = CLIENT_CONFIG_FILE_TEMPLATE % fierro_instance

    def shortDescription(self):
        if self.fierro_instance:
            return '%s (instancia %s) (%s)' % (self.test_method_name,
                                               self.fierro_instance,
                                               '.'.join(self.id().split('.')[:-1]))

    def test_locale_forzado_en_configuracion(self):
        lang = get_shell_variable(self.client_config_file, 'LANG')
        self.assertEquals(lang, "es_AR.ISO-8859-1")

        lc_all = get_shell_variable(self.client_config_file, 'LC_ALL')
        self.assertEquals(lc_all, "es_AR.ISO-8859-1")

    def test_se_puede_obtener_lista_de_sucursales_de_servidor(self):
        import Pyro.core

        pyro_loc = get_shell_variable(self.client_config_file, 'SERVER')

        pyro_loc = '%s/%s' % (pyro_loc, 'dispatcher')
        pyro_server = Pyro.core.getProxyForURI(pyro_loc)
        pyro_server._setTimeout(5)
        pyro_server.run("/login", "getSucursales", ())

    def test_version_servidor_coincide_con_version_cliente(self):
        from colofon.client.ipc.initManagers import getLoginManager
        from colofon.client.version import VERSION as client_version
        pyro_loc = get_shell_variable(self.client_config_file, 'SERVER')
        login_manager, pyro_server = getLoginManager(pyro_loc)
        server_version = login_manager.exchangeVersion()
        self.assertEquals(client_version, server_version)

    def test_vista_html_funciona(self):
        import urllib
        web_server = get_shell_variable(self.client_config_file, 'WEBSERVER')

        query_view = urllib.urlopen('http://%s/catalogo/query_point.spy' % web_server)

        self.assertIn('<title>query_point.spy</title>', query_view.read())

    def test_version_wx_correcta(self):
        import wx
        self.assertEquals(wx.VERSION, (2, 6, 4, 0, ''))


def load_tests(loader, tests, pattern):
    suite = unittest.TestSuite()
    if 'fierroclient' not in conf.TEST_COMPONENTS:
        return suite

    test_cases = loader.getTestCaseNames(TestFierroClient)

    for instance in conf.FIERROCLIENT_INSTANCES:
        for test_case in test_cases:
            suite.addTest(TestFierroClient(test_case, fierro_instance=instance))

    return suite
